@@ -33,10 +33,8 @@
 extern "C" {
 #endif
 
-#define container_of(ptr, type, member) ({                              \
-        const __typeof__(((type *)0)->member ) *__mptr = (ptr);         \
-        (type*)((void*)__mptr - offsetof(type, member));                \
-     })
+#define container_of(ptr, type, member)                                 \
+    (type*)((uint8_t *)ptr - offsetof(type, member))
 
 /// @brief Safe downcast using container_of().
 ///
