@@ -27,6 +27,7 @@
 #include <string.h>
 #include <xcb/xcb.h>
 
+#include "wcore_attrib_list.h"
 #include "wcore_error.h"
 
 #include "glx_config.h"
@@ -52,14 +53,25 @@ glx_window_destroy(struct wcore_window *wc_self)
 struct wcore_window*
 glx_window_create(struct wcore_platform *wc_plat,
                   struct wcore_config *wc_config,
-                  int width,
-                  int height)
+                  int32_t width,
+                  int32_t height,
+                  const intptr_t attrib_list[])
 {
     struct glx_window *self;
     struct glx_display *dpy = glx_display(wc_config->display);
     struct glx_config *config = glx_config(wc_config);
     bool ok = true;
 
+    if (width == -1 && height == -1) {
+        width = DisplayWidth(dpy->x11.xlib, dpy->x11.screen);
+        height = DisplayHeight(dpy->x11.xlib, dpy->x11.screen);
+    }
+
+    if (wcore_attrib_list_length(attrib_list) > 0) {
+        wcore_error_bad_attribute(attrib_list[0]);
+        return NULL;
+    }
+
     self = wcore_calloc(sizeof(*self));
     if (self == NULL)
         return NULL;
