@@ -38,10 +38,14 @@ struct wcore_platform;
 
 struct wayland_window {
     struct wl_surface *wl_surface;
+    struct xdg_surface *xdg_surface;
+    struct xdg_toplevel *xdg_toplevel;
     struct wl_shell_surface *wl_shell_surface;
     struct wl_egl_window *wl_window;
 
     struct wegl_surface wegl;
+
+    int32_t window_width, window_height;
 };
 
 static inline struct wayland_window*
